@@ -37,13 +37,21 @@ bool parserMobileBahnDe::supportsGps()
 ResultInfo parserMobileBahnDe::parseJourneyData(QByteArray data)
 {
     QBuffer readBuffer;
-    readBuffer.setData(data);
+
+    QString element = data;
+
+    //Remove misformed html
+    QRegExp ahrefReg = QRegExp("class=\"arrowlink\" href=\"(.*)\"");
+    ahrefReg.setMinimal(true);
+    element.replace(ahrefReg, "");
+
+    readBuffer.setData(element.toAscii());
     readBuffer.open(QIODevice::ReadOnly);
 
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for Header infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div[@class='haupt']/span[@class='bold']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/div[@class='haupt']/span[@class='bold']/string()");
 
     QStringList headerResults;
     if (!query.evaluateTo(&headerResults))
@@ -206,6 +214,12 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             QBuffer readBuffer;
             QString element = "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body>\n" + regexp.cap(0) + "\n</body>\n</html>\n";
 
+            //Remove misformed html
+            QRegExp ahrefReg = QRegExp("class=\"arrowlink\" href=\"(.*)\"");
+            ahrefReg.setMinimal(true);
+            element.replace(ahrefReg, "");
+            element.replace("&nbsp;", " ");
+
             readBuffer.setData(element.toAscii());
             readBuffer.open(QIODevice::ReadOnly);
 
@@ -408,12 +422,19 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
 
     //qDebug() <<filebuffer->buffer();
 
+    QString element = filebuffer->buffer();
+
+    //Remove misformed html
+    QRegExp ahrefReg = QRegExp("class=\"arrowlink\" href=\"(.*)\"");
+    ahrefReg.setMinimal(true);
+    element.replace(ahrefReg, "");
+
     //Check if we need do a search by id, sometimes the search for the exact name
     //returns a selectbox again, so we check for it and if there are selectboxes
     //we search by the ids we get as response
 
     QBuffer readBuffer;
-    readBuffer.setData(filebuffer->buffer());
+    readBuffer.setData(element.toAscii());
     readBuffer.open(QIODevice::ReadOnly);
 
     QXmlQuery query;
